package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.EquipmentExtension;
import com.dcs.hnyz.domain.vo.EquipmentExtensionFormVO;

/**
 * 设备拓展管理Mapper接口
 * 
 * @author hmy
 * @date 2025-04-23
 */
public interface EquipmentExtensionMapper extends BaseMapper<EquipmentExtension>
{
    /**
     * 查询设备拓展管理
     * 
     * @param id 设备拓展管理主键
     * @return 设备拓展管理
     */
    public EquipmentExtension selectEquipmentExtensionById(Long id);

    /**
     * 查询设备拓展管理列表
     * 
     * @param equipmentExtension 设备拓展管理
     * @return 设备拓展管理集合
     */
    public List<EquipmentExtension> selectEquipmentExtensionList(EquipmentExtension equipmentExtension);

    /**
     * 新增设备拓展管理
     * 
     * @param equipmentExtension 设备拓展管理
     * @return 结果
     */
    public int insertEquipmentExtension(EquipmentExtension equipmentExtension);

    /**
     * 修改设备拓展管理
     * 
     * @param equipmentExtension 设备拓展管理
     * @return 结果
     */
    public int updateEquipmentExtension(EquipmentExtension equipmentExtension);

    /**
     * 删除设备拓展管理
     * 
     * @param id 设备拓展管理主键
     * @return 结果
     */
    public int deleteEquipmentExtensionById(Long id);

    /**
     * 批量删除设备拓展管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEquipmentExtensionByIds(Long[] ids);

    /**
     * 查询设备拓展管理表单
     * @param equipmentExtensionFormVo
     * @return
     */
    List<EquipmentExtensionFormVO> getEquipmentExtensionFormList(EquipmentExtensionFormVO equipmentExtensionFormVo);
}
